| Title: | Runs a 'Shiny' App as Demo or Lists All Demo 'Shiny' Apps |
|---|---|
| Description: | Mimics the demo functionality for 'Shiny' apps in a package. Apps stored to the package subdirectory 'inst/shiny' can be called by demoShiny(topic). |
| Authors: | Sigbert Klinke [aut, cre] |
| Maintainer: | Sigbert Klinke <[email protected]> |
| License: | GPL-3 |
| Version: | 0.2 |
| Built: | 2026-05-21 09:22:27 UTC |
| Source: | https://github.com/sigbertklinke/demoshiny |
Runs a Shiny app as demo or shows an overview of all Shiny demo apps related to a topic.
If more than one app relates to topic a list of apps is returned otherwise the app is run.
For more details see vignettes('demoShiny').
demoShiny(topic, verbose = FALSE)demoShiny(topic, verbose = FALSE)
topic |
character: the topic which should be demonstrated |
verbose |
logical: should file locations printed, too (default: |
invisibly a data frame with topic, info and file location
# collect all apps of loaded packages demoShiny() demoShiny(verbose=TRUE) # collect all apps of the package demoShiny or with the name demoShiny demoShiny('demoShiny') if(interactive()) { demoShiny('demoShiny::hist') demoShiny('silhouette') # use partial matching demoShiny('silh') }# collect all apps of loaded packages demoShiny() demoShiny(verbose=TRUE) # collect all apps of the package demoShiny or with the name demoShiny demoShiny('demoShiny') if(interactive()) { demoShiny('demoShiny::hist') demoShiny('silhouette') # use partial matching demoShiny('silh') }