Welcome to ClientVPS Mirrors

Help for package demoShiny
Title: Runs a 'Shiny' App as Demo or Lists All Demo 'Shiny' Apps
Version: 0.1
Description: Mimics the demo functionality for 'Shiny' apps in a package. Apps stored to the package subdirectory inst/shiny can be called by demoShiny(topic).
Depends: shiny
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.0.2
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2020-01-13 11:58:23 UTC; sigbert
Author: Sigbert Klinke [aut, cre]
Maintainer: Sigbert Klinke <sigbert@hu-berlin.de>
Repository: CRAN
Date/Publication: 2020-01-16 10:30:07 UTC

demoShiny

Description

Runs a Shiny app as demo or shows an overview of all Shiny demo apps related to a topic. If more than one app relates to topic a list of apps is returned otherwise the app is run. For more details see vignettes('demoShiny').

Usage

demoShiny(topic)

Arguments

topic

character: the topic which should be demonstrated

Value

nothing

Examples

# collect all apps of loaded packages
demoShiny() 
# collect all apps of the package demoShiny or with the name demoShiny
demoShiny('demoShiny') 
if(interactive()) {
  demoShiny('demoShiny::hist') 
  demoShiny('silhouette') 
  # use partial matching
  demoShiny('silh') 
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.